<template>
    <div class="flex-center light-type">
        <div v-if="msg">
            <div class="err-message">
                <i class="el-icon-warning"></i><br />
                {{ this.msg }}
            </div>
        </div>
        <div v-if="binding" class="mobile-form">
            <div class="welcome-title mobile-title">
                请输入改革报表填报系统使用人员账号
            </div>
            <van-form @submit="onSubmit">
                <van-field
                    v-model="login.account"
                    name="用户名"
                    label="用户名"
                    placeholder="用户名"
                    :rules="[{required: true, message: '请填写用户名'}]"
                />
                <van-field
                    v-model="login.password"
                    type="password"
                    name="密码"
                    label="密码"
                    placeholder="密码"
                    :rules="[{required: true, message: '请填写密码'}]"
                />
                <div style="margin: 16px">
                    <van-button round block type="info" native-type="submit"
                        >提交</van-button
                    >
                </div>
            </van-form>
        </div>
    </div>
</template>

<script>
import dd from 'gdt-jsapi'
import {Loading} from 'element-ui'
export default {
    name: 'jumping',
    data() {
        var checkAccount = (rule, value, callback) => {
            if (!value) {
                return callback(new Error('请输入账号'))
            }
            if (/^[a-zA-Z0-9_-]{2,20}$/.test(value)) {
                return callback()
            } else {
                return callback(new Error('账号格式不符合规范'))
            }
        }
        return {
            loading: null,
            loginLoading: false,
            login: {
                account: '',
                password: '',
            },
            params: {
                account: '',
                openid: '',
            },
            rules: {
                account: [
                    {validator: checkAccount, trigger: 'blur'},
                    {required: true, message: '请输入账号', trigger: 'blur'},
                ],
                password: [
                    {required: true, message: '请输入密码', trigger: 'blur'},
                ],
            },
            msg: '',
            binding: false,
            code: '',
            type: '',
            res: null,
        }
    },
    mounted() {
        this.openFullScreen()
        dd.ready(() => {
            dd.getAuthCode({}).then((result) => {
                this.res = result
                this.type = '获取code'
                let code
                if (result.code) {
                    this.code = result.code
                    code = result.code
                    this.ykzLogin(code)
                }
            })
        })
    },
    methods: {
        ykzLogin(code) {
            this.$store.dispatch('login/loginByYKZ', code).then((user) => {
                this.res = user
                this.type = 'code登录'
                if (user.state === undefined) {
                    if (user.loginStatus) {
                        this.$store.dispatch('login/getAllDict')
                        this.$router.push('/DistrictReformMobile')
                    } else {
                        this.binding = true
                        this.params = {
                            account: user.account,
                            openid: user.openid,
                        }
                    }
                } else if (user.state === false) {
                    this.msg = user.message
                    this.showMsg()
                }
            })
        },
        showMsg() {
            if (this.loading) this.loading.close()
        },
        openFullScreen() {
            this.loading = Loading.service({
                lock: true,
                text: '改革报表加载中......',
                spinner: 'el-icon-loading',
                background: 'rgba(255, 255, 255, 0.6)',
            })
        },
        onSubmit(values) {
            this.handleLogin()
        },
        handleLogin() {
            this.loginLoading = true
            if (!this.params.account || !this.params.openid) {
                this.$message.warning('愉快政验证已失效，请重新验证！')
                return
            }
            let data = {
                loginData: this.login,
                ykzData: {
                    ykzAccount: this.params.account,
                    ykzAccountId: this.params.openid,
                },
            }
            this.$store
                .dispatch('login/bindingYKZ', data)
                .then((user) => {
                    console.log(user)
                    this.res = user
                    this.type = '绑定'
                    if (user.loginStatus && user.loginStatus == true) {
                        //获取前台页面
                        this.$store.dispatch('login/getAllDict')
                        this.$router.push({
                            path: `/MajorProjectsMobile`,
                        })
                    } else if (user.loginStatus == false) {
                        this.msg = user.message
                            ? user.message
                            : '登录失败，请重新验证！'
                        this.$message.warning(msg)
                    }
                })
                .catch((msg) => {
                    console.log(msg)
                    this.$message.warning(msg)
                    this.loginLoading = false
                })
        },
    },
    beforeDestroy() {
        if (this.loading) this.loading.close()
    },
}
</script>

<style lang="scss" scoped>
.light-type{
    width: 100%;
    height: 100%;
    background: #f2f2f2;
}
.flex-center{
    display: flex;
    justify-content: center;
    align-items: center;
}
.binding{
    width: 460px;
}
.login-form{
    width: 400px;
    margin: 20px auto;
    text-align: center;
}
.welcome-title {
    color: #12bae7;
    margin: 20px 0 50px 0;
    font-size: 20px;
    font-weight: bold;
    letter-spacing: 2px;
    text-align: center;
    font-family: Roboto, Microsoft YaHei, Sans-serif;
}
.welcome-title.mobile-title{
     margin-bottom: 2rem;
     font-size:16PX;

}
.login-btn {
    width: 300px;
    margin-top: 20px;
    border: 1px solid #2182f7;
    background-color: #2182f7;
}
.err-message{
    color: #1E1E1E;
    text-align: center;
    i{
        font-size: 20PX;
        color: #E84646;
        margin-bottom: 10PX;
    }
}
.mobile-form{
    background-color: #fff;
    padding: 4rem 2rem 2rem 2rem;
    border-radius: 10PX;
}
</style>